==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/ja.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "ストレージが利用できません",
    "Storage invalid" : "ストレージが無効です",
    "Unknown error" : "不明なエラー",
    "Unable to set upload directory." : "アップロードディレクトリを設定できません。",
    "Invalid Token" : "無効なトークン",
    "No file was uploaded. Unknown error" : "ファイルは何もアップロードされていません。不明なエラー",
    "There is no error, the file uploaded with success" : "エラーはありません。ファイルのアップロードは成功しました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "アップロードされたファイルはphp.ini の upload_max_filesize に設定されたサイズを超えています:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The uploaded file was only partially uploaded" : "アップロードファイルは一部分だけアップロードされました",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Failed to write to disk" : "ディスクへの書き込みに失敗しました",
    "Not enough storage available" : "ストレージに十分な空き容量がありません",
    "The target folder has been moved or deleted." : "対象のフォルダーは移動されたか、削除されました。",
    "Upload failed. Could not find uploaded file" : "アップロードに失敗しました。アップロード済みのファイルを見つけることができませんでした。",
    "Upload failed. Could not get file info." : "アップロードに失敗しました。ファイル情報を取得できませんでした。",
    "Invalid directory." : "無効なディレクトリです。",
    "Files" : "ファイル",
    "All files" : "すべてのファイル",
    "File could not be found" : "ファイルは見つかりませんでした。",
    "Home" : "ホーム",
    "Close" : "閉じる",
    "Favorites" : "お気に入り",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリもしくは0バイトのため {filename} をアップロードできません",
    "Total file size {size1} exceeds upload limit {size2}" : "合計ファイルサイズ {size1} はアップロード制限 {size2} を超過しています。",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Error uploading file \"{fileName}\": {message}" : "ファイル\"{fileName}\"のアップロードエラー: {message}",
    "Could not get result from server." : "サーバーから結果を取得できませんでした。",
    "Uploading..." : "アップロード中...",
    "..." : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "ファイル転送を実行中です。今このページから移動するとアップロードが中止されます。",
    "Actions" : "アクション",
    "Download" : "ダウンロード",
    "Rename" : "名前の変更",
    "Delete" : "削除",
    "Disconnect storage" : "ストレージを切断する",
    "Unshare" : "共有解除",
    "Details" : "詳細",
    "Select" : "選択",
    "Pending" : "中断",
    "Unable to determine date" : "更新日不明",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"は既に存在するため作成できませんでした",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" は既に存在するため作成できませんでした",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No entries in this folder match '{filter}'" : "このフォルダー内で '{filter}' にマッチするものはありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードもしくは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Your storage is full, files can not be updated or synced anymore!" : "あなたのストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} のストレージはほぼ一杯です。({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "ストレージがほぼ一杯です（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : [" '{filter}' にマッチ"],
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Favorite" : "お気に入り",
    "Local link" : "ローカルリンク",
    "Folder" : "フォルダー",
    "New folder" : "新しいフォルダー",
    "{newname} already exists" : "{newname} はすでに存在します",
    "Upload" : "アップロード",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーを<strong>作成</strong>したとき",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーを<strong>変更</strong>したとき",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>お気に入りファイル</strong>の作成と変更の通知を制限する<em>(ストリームのみ)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーを<strong>削除</strong>したとき",
    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーを<strong>復元</strong>したとき",
    "You created %1$s" : "あなたは %1$s を作成しました",
    "%2$s created %1$s" : "%2$s は%1$s を作成しました",
    "%1$s was created in a public folder" : "公開フォルダーに %1$s が作成されました",
    "You changed %1$s" : "あなたは %1$s を変更しました",
    "%2$s changed %1$s" : "%2$s は%1$s を変更しました",
    "You deleted %1$s" : "あなたは %1$s を削除しました",
    "%2$s deleted %1$s" : "%2$s は %1$s を削除しました",
    "You restored %1$s" : "%1$s を復元しました",
    "%2$s restored %1$s" : "%2$s は、 %1$s を復元しました",
    "Changed by %2$s" : "%2$s により更新",
    "Deleted by %2$s" : "%2$s により削除",
    "Restored by %2$s" : "%2$s により復元",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "File handling" : "ファイル操作",
    "Maximum upload size" : "最大アップロードサイズ",
    "max. possible: " : "最大容量: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
    "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
    "Settings" : "設定",
    "Show hidden files" : "隠しファイルを表示",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">WebDAV 経由でファイルにアクセス</a> するにはこのアドレスを利用してください",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、サーバーで規定された最大サイズを超えています。",
    "No favorites" : "お気に入りなし",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/ja.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ストレージが一時的に利用できません",
    "Storage invalid" : "ストレージが無効です",
    "Unknown error" : "不明なエラー",
    "All files" : "すべてのファイル",
    "Saved" : "保存されました",
    "There was an error saving" : "保存中にエラーが発生しました",
    "File could not be found" : "ファイルは見つかりませんでした。",
    "Home" : "ホーム",
    "Close" : "閉じる",
    "Favorites" : "お気に入り",
    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
    "Upload cancelled." : "アップロードはキャンセルされました。",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリもしくは0バイトのため {filename} をアップロードできません",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
    "Target folder \"{dir}\" does not exist any more" : "ターゲットフォルダー \"{dir}\" はもう存在しません",
    "Target folder does not exist any more" : "ターゲットフォルダー はもう存在しません",
    "Not enough free space" : "空き容量が不足しています",
    "Uploading..." : "アップロード中...",
    "..." : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "ファイル転送を実行中です。今このページから移動するとアップロードが中止されます。",
    "Actions" : "アクション",
    "Download" : "ダウンロード",
    "Rename" : "名前の変更",
    "Delete" : "削除",
    "Disconnect storage" : "ストレージを切断する",
    "Unshare" : "共有解除",
    "Could not load info for file \"{file}\"" : "ファイル \"{file}\" の情報を読み込めませんでした",
    "Files" : "ファイル",
    "Details" : "詳細",
    "Select" : "選択",
    "Pending" : "中断",
    "Unable to determine date" : "更新日不明",
    "Invalid path" : "無効なパス",
    "This operation is forbidden" : "この操作は禁止されています",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
    "{newName} already exists" : "{newName} はすでに存在します",
    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できませんでした",
    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できませんでした",
    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
    "No entries in this folder match {filter}" : "このフォルダー内で {filter}にマッチするものはありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "{dirs} and {files}" : "{dirs} と {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n の隠しファイルを含む"],
    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードもしくは作成する権限がありません",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
    "New" : "新規作成",
    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
    "File name cannot be empty." : "ファイル名を空にすることはできません。",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Your storage is full, files can not be updated or synced anymore!" : "あなたのストレージは一杯です。ファイルの更新と同期はもうできません！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} のストレージはほぼ一杯です。({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "ストレージがほぼ一杯です（{usedSpacePercent}%）",
    "_matches '{filter}'_::_match '{filter}'_" : [" '{filter}' にマッチ"],
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n バイト"],
    "Favorited" : "お気に入り済",
    "Favorite" : "お気に入り",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "プライベートリンク: ファイルやフォルダーにアクセスできる権限のあるユーザーのみ利用できます。自分用のパーマネントリンクや、共有している他のユーザーにピンポイントに指定することができます。",
    "Folder" : "フォルダー",
    "New folder" : "新しいフォルダー",
    "{newname} already exists" : "{newname} はすでに存在します",
    "Upload" : "アップロード",
    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーを<strong>作成</strong>したとき",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーを<strong>変更</strong>したとき",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>お気に入りファイル</strong>の作成と変更の通知を制限する<em>(ストリームのみ)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーを<strong>削除</strong>したとき",
    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーを<strong>復元</strong>したとき",
    "You created %1$s" : "あなたは %1$s を作成しました",
    "%2$s created %1$s" : "%2$s は%1$s を作成しました",
    "%1$s was created in a public folder" : "公開フォルダーに %1$s が作成されました",
    "You changed %1$s" : "あなたは %1$s を変更しました",
    "%2$s changed %1$s" : "%2$s は%1$s を変更しました",
    "You deleted %1$s" : "あなたは %1$s を削除しました",
    "%2$s deleted %1$s" : "%2$s は %1$s を削除しました",
    "You restored %1$s" : "%1$s を復元しました",
    "%2$s restored %1$s" : "%2$s は、 %1$s を復元しました",
    "Changed by %2$s" : "%2$s により更新",
    "Deleted by %2$s" : "%2$s により削除",
    "Restored by %2$s" : "%2$s により復元",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "File handling" : "ファイル操作",
    "Maximum upload size" : "最大アップロードサイズ",
    "max. possible: " : "最大容量: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM の場合は値を変更後、反映されるのに5分程度かかります。",
    "Missing permissions to edit from here." : "ここから編集するための権限がありません。",
    "Settings" : "設定",
    "Show hidden files" : "隠しファイルを表示",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">WebDAV 経由でファイルにアクセス</a> するにはこのアドレスを利用してください",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、サーバーで規定された最大サイズを超えています。",
    "No favorites" : "お気に入りなし",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "Text file" : "テキストファイル",
    "New text file.txt" : "新規のテキストファイル作成"
},
"nplurals=1; plural=0;");
